@@ -1,7 +1,6 @@
 import numpy as np
 from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
 from sklearn.tree import _tree
-from sklearn.tree import _tree
 from typing import Union, List, Tuple
 
 
@@ -97,7 +96,7 @@ def tree_to_code(clf, feature_names):
         # space=node_depth[i] * "\t", node=i))
         else:
             s += f"{feature_names[feature[i]]} <= {threshold[i]}"
-    return s + '\n'
+    return f"\033[96m{s}\033[00m\n"
 
 
 def itemsets_to_rules(itemsets: List[Tuple]) -> List[str]:
@@ -129,11 +128,11 @@ def dict_to_rule(rule, clf_feature_dict):
             condition['operator'],
             condition['pivot']
         )
-    
+
     return output[:-5]
 
-def single_discretized_feature_to_rule(feat: str) -> str:
 
+def single_discretized_feature_to_rule(feat: str) -> str:
     # categorical feature
     if '_to_' not in feat:
         return f'{feat} > 0.5'
@@ -145,12 +144,12 @@ def single_discretized_feature_to_rule(feat: str) -> str:
 
     lower_to_upper_len = 1 + len(lower_value) + 4 + len(upper_value)
     feature_name = feat[:-lower_to_upper_len]
-    
+
     if lower_value == '-inf':
         rule = f'{feature_name} <= {upper_value}'
     elif upper_value == 'inf':
         rule = f'{feature_name} > {lower_value}'
     else:
         rule = f'{feature_name} > {lower_value} and {feature_name} <= {upper_value}'
-    
+
     return rule
